package cn.com.infosec.asn1.ess;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.nist.NISTObjectIdentifiers;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.IssuerSerial;

public class ESSCertIDv2 extends ASN1Encodable {
   private static final AlgorithmIdentifier DEFAULT_ALG_ID;
   private AlgorithmIdentifier hashAlgorithm;
   private byte[] certHash;
   private IssuerSerial issuerSerial;

   static {
      DEFAULT_ALG_ID = new AlgorithmIdentifier(NISTObjectIdentifiers.id_sha256, DERNull.INSTANCE);
   }

   public static ESSCertIDv2 getInstance(Object o) {
      if (o != null && !(o instanceof ESSCertIDv2)) {
         if (o instanceof ASN1Sequence) {
            return new ESSCertIDv2((ASN1Sequence)o);
         } else {
            throw new IllegalArgumentException("unknown object in 'ESSCertIDv2' factory : " + o.getClass().getName() + ".");
         }
      } else {
         return (ESSCertIDv2)o;
      }
   }

   public ESSCertIDv2(ASN1Sequence seq) {
      if (seq.size() != 2 && seq.size() != 3) {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      } else {
         int var2 = 0;
         if (seq.getObjectAt(0) instanceof ASN1OctetString) {
            this.hashAlgorithm = DEFAULT_ALG_ID;
         } else {
            int var10002 = var2;
            var2 = 1;
            this.hashAlgorithm = AlgorithmIdentifier.getInstance(seq.getObjectAt(var10002).getDERObject());
         }

         this.certHash = ASN1OctetString.getInstance(seq.getObjectAt(var2++).getDERObject()).getOctets();
         if (seq.size() > var2) {
            this.issuerSerial = new IssuerSerial(ASN1Sequence.getInstance(seq.getObjectAt(var2).getDERObject()));
         }

      }
   }

   public ESSCertIDv2(AlgorithmIdentifier algId, byte[] certHash) {
      this(algId, certHash, (IssuerSerial)null);
   }

   public ESSCertIDv2(AlgorithmIdentifier algId, byte[] certHash, IssuerSerial issuerSerial) {
      if (algId == null) {
         this.hashAlgorithm = DEFAULT_ALG_ID;
      } else {
         this.hashAlgorithm = algId;
      }

      this.certHash = certHash;
      this.issuerSerial = issuerSerial;
   }

   public AlgorithmIdentifier getHashAlgorithm() {
      return this.hashAlgorithm;
   }

   public byte[] getCertHash() {
      return this.certHash;
   }

   public IssuerSerial getIssuerSerial() {
      return this.issuerSerial;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      if (!this.hashAlgorithm.equals(DEFAULT_ALG_ID)) {
         var1.add(this.hashAlgorithm);
      }

      var1.add((new DEROctetString(this.certHash)).toASN1Object());
      IssuerSerial var2;
      if ((var2 = this.issuerSerial) != null) {
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
